@@ -360,6 +360,12 @@ class Humed():
         # 2a - Await hume message over zmp
         while True:
             hume = {}
+            poller = zmq.Poller()
+            poller.register(sock, zmq.POLLIN)
+            if poller.poll(1000):
+                msg = sock.recv()
+            else:
+                continue
             try:
                 hume = json.loads(sock.recv())
             except Exception as ex:
@@ -382,9 +388,12 @@ def main():
     config = confuse.Configuration('humed')
     # Config defaults
     config['endpoint'] = 'tcp://127.0.0.1:198'
-    config['rsyslog']['server'] = 'localhost'
+    config['rsyslog']['server'] = 'syslog.example.net'
     config['rsyslog']['proto'] = 'udp'
     config['rsyslog']['port'] = 514
+    config['logstash']['host'] = '127.0.0.1'
+    config['logstash']['port'] = 24224
+    config['slack']['webhook_url'] = 'https://example.net/some/webhook/path'
     parser = argparse.ArgumentParser()
     config['debug'] = DEBUG
     parser.add_argument('--debug',
